==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.md <==
# AmazonSimpleNotificationServiceTopic


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')
```



| Illustration | AmazonSimpleNotificationServiceTopic | AmazonSimpleNotificationServiceTopicCard | AmazonSimpleNotificationServiceTopicGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.png) | ![illustration for AmazonSimpleNotificationServiceTopic](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.Local.png) | ![illustration for AmazonSimpleNotificationServiceTopicCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopicCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceTopicGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopicGroup.Local.png) |




## AmazonSimpleNotificationServiceTopic

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopic
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopic('AmazonSimpleNotificationServiceTopic', 'Amazon Simple Notification Service Topic', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopic
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopic('AmazonSimpleNotificationServiceTopic', 'Amazon Simple Notification Service Topic', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceTopicCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicCard('AmazonSimpleNotificationServiceTopicCard', 'Amazon Simple Notification Service Topic Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicCard('AmazonSimpleNotificationServiceTopicCard', 'Amazon Simple Notification Service Topic Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceTopicGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicGroup('AmazonSimpleNotificationServiceTopicGroup', 'Amazon Simple Notification Service Topic Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicGroup('AmazonSimpleNotificationServiceTopicGroup', 'Amazon Simple Notification Service Topic Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.md <==
# AmazonSimpleNotificationServiceTopic


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')
```



| Illustration | AmazonSimpleNotificationServiceTopic | AmazonSimpleNotificationServiceTopicCard | AmazonSimpleNotificationServiceTopicGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.png) | ![illustration for AmazonSimpleNotificationServiceTopic](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic.Local.png) | ![illustration for AmazonSimpleNotificationServiceTopicCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopicCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceTopicGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopicGroup.Local.png) |




## AmazonSimpleNotificationServiceTopic

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopic
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopic('AmazonSimpleNotificationServiceTopic', 'Amazon Simple Notification Service Topic', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopic
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopic('AmazonSimpleNotificationServiceTopic', 'Amazon Simple Notification Service Topic', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceTopicCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicCard('AmazonSimpleNotificationServiceTopicCard', 'Amazon Simple Notification Service Topic Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicCard('AmazonSimpleNotificationServiceTopicCard', 'Amazon Simple Notification Service Topic Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceTopicGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicGroup('AmazonSimpleNotificationServiceTopicGroup', 'Amazon Simple Notification Service Topic Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceTopicGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceTopic')

' renders the element
AmazonSimpleNotificationServiceTopicGroup('AmazonSimpleNotificationServiceTopicGroup', 'Amazon Simple Notification Service Topic Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
